@@ -30,7 +30,7 @@ pkg_dir = os.path.dirname(root_dir)
 pkg_join = lambda *paths: os.path.join(pkg_dir, *paths)
 
 # TODO: Change to use ini format? (Or yaml or toml?)
-wads_configs_file = rjoin(data_dir, "wads_configs.json")
+wads_configs_file = os.getenv("WADS_CONFIGS_FILE", rjoin(data_dir, "wads_configs.json"))
 try:
     wads_configs = json.load(open(wads_configs_file))
 except FileNotFoundError:
